@@ -28,8 +28,6 @@ def get_image(path):
 def env(**kwargs):
     env = raw_env(**kwargs)
     env = wrappers.AssertOutOfBoundsWrapper(env)
-    default_val = 1
-    env = wrappers.NanNoOpWrapper(env, default_val, "setting action to 1")
     env = wrappers.OrderEnforcingWrapper(env)
     return env
 
@@ -41,8 +39,8 @@ class raw_env(AECEnv, EzPickle):
 
     metadata = {'render.modes': ['human', "rgb_array"]}
 
-    def __init__(self, spawn_rate=20, num_archers=2, num_knights=2, killable_knights=True, killable_archers=True, pad_observation=True, black_death=True, line_death=False, max_cycles=900):
-        EzPickle.__init__(self, spawn_rate, num_archers, num_knights, killable_knights, killable_archers, pad_observation, black_death, line_death, max_cycles)
+    def __init__(self, spawn_rate=20, num_archers=2, num_knights=2, killable_knights=True, killable_archers=True, pad_observation=True, line_death=False, max_cycles=900):
+        EzPickle.__init__(self, spawn_rate, num_archers, num_knights, killable_knights, killable_archers, pad_observation, line_death, max_cycles)
         # Game Constants
         self.ZOMBIE_SPAWN = spawn_rate
         self.WIDTH = 1280
@@ -52,7 +50,6 @@ class raw_env(AECEnv, EzPickle):
         self.pad_observation = pad_observation
         self.killable_knights = killable_knights
         self.killable_archers = killable_archers
-        self.black_death = black_death
         self.line_death = line_death
         self.has_reset = False
         self.seed()
@@ -81,12 +78,12 @@ class raw_env(AECEnv, EzPickle):
         self.archer_list = pygame.sprite.Group()
         self.knight_list = pygame.sprite.Group()
 
-        # If black_death, this represents agents to remove at end of cycle
-        self.kill_list = []
-
         self.num_archers = num_archers
         self.num_knights = num_knights
 
+        # Represents agents to remove at end of cycle
+        self.kill_list = []
+
         # Initializing Pygame
         self.render_on = False
         pygame.init()
@@ -330,7 +327,6 @@ class raw_env(AECEnv, EzPickle):
                 all_sprites.remove(sword)
                 zombie_list.remove(zombie)
                 all_sprites.remove(zombie)
-                # score += 1
                 sword.knight.score += 1
         return zombie_list, sword_list, all_sprites, score
 
@@ -475,9 +471,9 @@ class raw_env(AECEnv, EzPickle):
         done = not self.run or self.frames >= self.max_cycles
         self.dones = {a: done for a in self.agents}
 
-        if self._agent_selector.is_last() and not self.black_death:
+        if self._agent_selector.is_last():
             _live_agents = self.agents[:]
-            # self.agents must be recreated
+
             for k in self.kill_list:
                 self.dones[k] = True
                 _live_agents.remove(k)
@@ -515,7 +511,8 @@ class raw_env(AECEnv, EzPickle):
             self.enable_render()
 
         observation = np.array(pygame.surfarray.pixels3d(self.WINDOW))
-        pygame.display.flip()
+        if mode == "human":
+            pygame.display.flip()
         return np.transpose(observation, axes=(1, 0, 2)) if mode == "rgb_array" else None
 
     def close(self):
@@ -612,6 +609,6 @@ class raw_env(AECEnv, EzPickle):
 # The original code for this game, that was added by Justin Terry, was
 # created by Dipam Patel in a different repository (hence the git history)
 
-# Game art puchased from https://finalbossblues.itch.io/time-fantasy-monsters
+# Game art purchased from https://finalbossblues.itch.io/time-fantasy-monsters
 
 # and https://finalbossblues.itch.io/icons
