@@ -74,13 +74,10 @@ def env(**kwargs):
     env = raw_env(**kwargs)
 
     if env.continuous:
-        default_val = np.zeros((1,))
         env = wrappers.ClipOutOfBoundsWrapper(env)
     else:
-        default_val = 0
         env = wrappers.AssertOutOfBoundsWrapper(env)
 
-    env = wrappers.NanNoOpWrapper(env, default_val, "setting action to 0")
     env = wrappers.OrderEnforcingWrapper(env)
     return env
 
@@ -364,7 +361,8 @@ class raw_env(AECEnv, EzPickle):
             self.rendering = True
 
         observation = np.array(pygame.surfarray.pixels3d(self.screen))
-        pygame.display.flip()
+        if mode == "human":
+            pygame.display.flip()
         return np.transpose(observation, axes=(1, 0, 2)) if mode == "rgb_array" else None
 
 
