@@ -12,7 +12,6 @@ def env(**kwargs):
     env = wrappers.CaptureStdoutWrapper(env)
     env = wrappers.TerminateIllegalWrapper(env, illegal_reward=-1)
     env = wrappers.AssertOutOfBoundsWrapper(env)
-    env = wrappers.NanNoOpWrapper(env, 26**2 * 2, "executing the 'do nothing' action.")
     env = wrappers.OrderEnforcingWrapper(env)
     return env
 
@@ -29,7 +28,7 @@ class raw_env(AECEnv):
         self.possible_agents = self.agents[:]
         self._agent_order = list(self.agents)
         self._agent_selector = agent_selector(self._agent_order)
-        self.infos = {i: {'legal_moves': []} for i in self.agents}
+        self.infos = {i: {} for i in self.agents}
 
         self.action_spaces = {name: spaces.Discrete(26 * 26 * 2 + 1) for name in self.agents}
 
@@ -41,8 +40,10 @@ class raw_env(AECEnv):
         for i in range(101, 195, 4):
             high[i] = 6.0
         high[194] = 7.5
-        self.observation_spaces = {i: spaces.Box(low=np.float32(low), high=np.float32(high), dtype=np.float32) for i in self.agents}
-
+        self.observation_spaces = {
+            i: spaces.Dict({'observation': spaces.Box(low=np.float32(low), high=np.float32(high), dtype=np.float32),
+                            'action_mask': spaces.Box(low=0, high=1, shape=(1353,), dtype=np.int8)})
+            for i in self.agents}
         self.double_roll = 0
 
     def seed(self, seed=None):
@@ -79,26 +80,31 @@ class raw_env(AECEnv):
                 roll = (-roll[0], -roll[1])
             self.roll = roll
 
-        valid_moves = bg_utils.get_valid_actions(self, self.roll)
-
-        if self.double_roll > 0:
-            self.handle_double_roll()
-            valid_moves = bg_utils.double_roll(valid_moves)
-            self.double_roll -= 1
-
-        legal_moves = np.array(bg_utils.to_gym_format(valid_moves, self.roll))
-        if len(legal_moves) == 0:
-            legal_moves = np.array([26**2 * 2])
-        legal_moves.sort()
-        opp_agent = bg_utils.opp_agent(self, self.agent_selection)
-        self.infos[self.agent_selection]['legal_moves'] = legal_moves
-        self.infos[opp_agent]['legal_moves'] = []
-
         self._accumulate_rewards()
         self._dones_step_first()
 
     def observe(self, agent):
-        return np.array(self.game.get_board_features(agent), dtype=np.float32).reshape(198,)
+        action_mask = np.zeros(1353, int)
+        observation = np.array(self.game.get_board_features(agent), dtype=np.float32).reshape(198, )
+        # only current agent can make legal moves
+        if agent == self.agent_selection:
+            valid_moves = bg_utils.get_valid_actions(self, self.roll)
+
+            if self.double_roll > 0:
+                self.handle_double_roll()
+                valid_moves = bg_utils.double_roll(valid_moves)
+                self.double_roll -= 1
+
+            legal_moves = bg_utils.to_gym_format(valid_moves, self.roll)
+            if len(legal_moves) == 0:
+                legal_moves = [26**2 * 2]
+        else:
+            legal_moves = []
+
+        for i in legal_moves:
+            action_mask[i] = 1
+
+        return {'observation': observation, 'action_mask': action_mask}
 
     def reset(self):
         self.agents = self.possible_agents[:]
@@ -127,11 +133,6 @@ class raw_env(AECEnv):
             self.colors[opp_agent] = WHITE
         self.roll = roll
 
-        legal_moves = np.array(bg_utils.to_gym_format(bg_utils.get_valid_actions(self, roll), roll))
-        legal_moves.sort()
-        self.infos[self.agent_selection]['legal_moves'] = legal_moves
-        self.infos[opp_agent]['legal_moves'] = []
-
     def render(self, mode='human'):
         assert mode in ['human'], print(mode)
         if mode == 'human':
