@@ -1,6 +1,3 @@
-# from __future__ import absolute_import, division, print_function
-from six.moves import range
-
 import itertools
 import copy
 import numpy as np
@@ -17,7 +14,6 @@ def env():
     env = wrappers.CaptureStdoutWrapper(env)
     env = wrappers.TerminateIllegalWrapper(env, illegal_reward=-1)
     env = wrappers.AssertOutOfBoundsWrapper(env)
-    env = wrappers.NaNRandomWrapper(env)
     env = wrappers.OrderEnforcingWrapper(env)
     return env
 
@@ -74,7 +70,8 @@ class raw_env(AECEnv):
 
         self.action_spaces = {name: spaces.Discrete(64 * 4) for name in self.agents}
         self.observation_spaces = {
-            name: spaces.Box(low=0, high=1, shape=(8, 8, 4), dtype="float64")
+            name: spaces.Dict({'observation': spaces.Box(low=0, high=1, shape=(8, 8, 4), dtype="float64"),
+                               'action_mask': spaces.Box(low=0, high=1, shape=(256,), dtype=np.int8)})
             for name in self.agents
         }
         self.observation = np.zeros((8, 8, 4))
@@ -95,10 +92,13 @@ class raw_env(AECEnv):
             # Rotate board to place black pieces at bottom
             obs = np.rot90(obs, 2, axes=(0, 1))
         self.observation = np.array(obs)
-        return self.observation
 
-    def seed(self, seed=None):
-        pass
+        legal_moves = self.legal_moves() if agent == self.agent_selection else []
+        action_mask = np.zeros(256, int)
+        for i in legal_moves:
+            action_mask[i] = 1
+
+        return {'observation': self.observation, 'action_mask': action_mask}
 
     def reset(self):
         self.ch = CheckersRules()
@@ -106,13 +106,12 @@ class raw_env(AECEnv):
         self.agents = self.possible_agents[:]
         self.agent_order = list(self.agents)
         self.agent_selection = self.agent_order[0]
+        self.infos = {name: {} for name in self.agents}
         self.observation = self.observe(self.agent_selection)
         self.last_turn = "black"
         self.rewards = {name: 0 for name in self.agents}
         self._cumulative_rewards = {name: 0 for name in self.agents}
         self.dones = {name: False for name in self.agents}
-        self.infos = {name: {"legal_moves": []} for name in self.agents}
-        self.infos[self.agent_selection]["legal_moves"] = self.legal_moves()
         self.winner = -1
 
     # Parse action from (256) action space into (32)x(32) action space
@@ -219,8 +218,6 @@ class raw_env(AECEnv):
 
             self.agent_selection = "player_0" if turn == "black" else "player_1"
 
-        self.infos[self.agent_selection]["legal_moves"] = self.legal_moves()
-
         if winner == "black":
             self.winner = 0
             self.rewards[self.agents[0]] = 1
