@@ -13,7 +13,6 @@ def env():
     env = wrappers.CaptureStdoutWrapper(env)
     env = wrappers.TerminateIllegalWrapper(env, illegal_reward=-1)
     env = wrappers.AssertOutOfBoundsWrapper(env)
-    env = wrappers.NaNRandomWrapper(env)
     env = wrappers.OrderEnforcingWrapper(env)
     return env
 
@@ -33,7 +32,10 @@ class raw_env(AECEnv):
         self._agent_selector = agent_selector(self.agents)
 
         self.action_spaces = {name: spaces.Discrete(8 * 8 * 73) for name in self.agents}
-        self.observation_spaces = {name: spaces.Box(low=0, high=1, shape=(8, 8, 20), dtype=np.bool) for name in self.agents}
+        self.observation_spaces = {name: spaces.Dict({
+            'observation': spaces.Box(low=0, high=1, shape=(8, 8, 20), dtype=np.bool),
+            'action_mask': spaces.Box(low=0, high=1, shape=(4672,), dtype=np.int8)
+        }) for name in self.agents}
 
         self.rewards = None
         self.dones = None
@@ -41,11 +43,15 @@ class raw_env(AECEnv):
 
         self.agent_selection = None
 
-    def seed(self, seed=None):
-        pass
-
     def observe(self, agent):
-        return chess_utils.get_observation(self.board, self.possible_agents.index(agent))
+        observation = chess_utils.get_observation(self.board, self.possible_agents.index(agent))
+        legal_moves = chess_utils.legal_moves(self.board) if agent == self.agent_selection else []
+
+        action_mask = np.zeros(4672, int)
+        for i in legal_moves:
+            action_mask[i] = 1
+
+        return {'observation': observation, 'action_mask': action_mask}
 
     def reset(self):
         self.has_reset = True
@@ -60,8 +66,7 @@ class raw_env(AECEnv):
         self.rewards = {name: 0 for name in self.agents}
         self._cumulative_rewards = {name: 0 for name in self.agents}
         self.dones = {name: False for name in self.agents}
-        self.infos = {name: {'legal_moves': []} for name in self.agents}
-        self.infos[self.agent_selection]['legal_moves'] = chess_utils.legal_moves(self.board)
+        self.infos = {name: {} for name in self.agents}
 
     def set_game_result(self, result_val):
         for i, name in enumerate(self.agents):
@@ -75,7 +80,7 @@ class raw_env(AECEnv):
             return self._was_done_step(action)
         current_agent = self.agent_selection
         current_index = self.agents.index(current_agent)
-        self.agent_selection = next_agent = self._agent_selector.next()
+        self.agent_selection = self._agent_selector.next()
 
         chosen_move = chess_utils.action_to_move(self.board, action, current_index)
         assert chosen_move in self.board.legal_moves
@@ -95,10 +100,6 @@ class raw_env(AECEnv):
             result = self.board.result(claim_draw=True)
             result_val = chess_utils.result_to_int(result)
             self.set_game_result(result_val)
-        else:
-            self.infos[current_agent] = {'legal_moves': []}
-            self.infos[next_agent] = {'legal_moves': next_legal_moves}
-            assert len(self.infos[next_agent]['legal_moves'])
 
         self._accumulate_rewards()
         self._dones_step_first()
