@@ -12,7 +12,6 @@ def env():
     env = wrappers.CaptureStdoutWrapper(env)
     env = wrappers.TerminateIllegalWrapper(env, illegal_reward=-1)
     env = wrappers.AssertOutOfBoundsWrapper(env)
-    env = wrappers.NaNRandomWrapper(env)
     env = wrappers.OrderEnforcingWrapper(env)
     return env
 
@@ -33,10 +32,10 @@ class raw_env(AECEnv):
         self.possible_agents = self.agents[:]
 
         self.action_spaces = {i: spaces.Discrete(7) for i in self.agents}
-        self.observation_spaces = {i: spaces.Box(low=0, high=1, shape=(6, 7, 2), dtype=np.int8) for i in self.agents}
-
-    def seed(self, seed=None):
-        pass
+        self.observation_spaces = {i: spaces.Dict({
+            'observation': spaces.Box(low=0, high=1, shape=(6, 7, 2), dtype=np.int8),
+            'action_mask': spaces.Box(low=0, high=1, shape=(7,), dtype=np.int8)
+        }) for i in self.agents}
 
     # Key
     # ----
@@ -58,7 +57,18 @@ class raw_env(AECEnv):
 
         cur_p_board = np.equal(board_vals, cur_player + 1)
         opp_p_board = np.equal(board_vals, opp_player + 1)
-        return np.stack([cur_p_board, opp_p_board], axis=2).astype(np.int8)
+
+        observation = np.stack([cur_p_board, opp_p_board], axis=2).astype(np.int8)
+        legal_moves = self._legal_moves() if agent == self.agent_selection else []
+
+        action_mask = np.zeros(7, int)
+        for i in legal_moves:
+            action_mask[i] = 1
+
+        return {'observation': observation, 'action_mask': action_mask}
+
+    def _legal_moves(self):
+        return [i for i in range(7) if self.board[i] == 0]
 
     # action in this case is a value from 0 to 6 indicating position to move on the flat representation of the connect4 board
     def step(self, action):
@@ -75,10 +85,6 @@ class raw_env(AECEnv):
 
         next_agent = self._agent_selector.next()
 
-        # update infos with valid moves
-        self.infos[self.agent_selection]['legal_moves'] = [i for i in range(7) if self.board[i] == 0]
-        self.infos[next_agent]['legal_moves'] = [i for i in range(7) if self.board[i] == 0]
-
         winner = self.check_for_winner()
 
         # check if there is a winner
@@ -105,7 +111,7 @@ class raw_env(AECEnv):
         self.rewards = {i: 0 for i in self.agents}
         self._cumulative_rewards = {name: 0 for name in self.agents}
         self.dones = {i: False for i in self.agents}
-        self.infos = {i: {'legal_moves': list(range(7))} for i in self.agents}
+        self.infos = {i: {} for i in self.agents}
 
         self._agent_selector = agent_selector(self.agents)
 
