@@ -14,8 +14,6 @@ def env(**kwargs):
     env = wrappers.CaptureStdoutWrapper(env)
     env = wrappers.TerminateIllegalWrapper(env, illegal_reward=-1)
     env = wrappers.AssertOutOfBoundsWrapper(env)
-    pass_action = 3
-    env = wrappers.NanNoOpWrapper(env, pass_action, "'checked' with action {}".format(pass_action))
     env = wrappers.OrderEnforcingWrapper(env)
     return env
 
