@@ -14,8 +14,6 @@ def env(**kwargs):
     env = wrappers.CaptureStdoutWrapper(env)
     env = wrappers.TerminateIllegalWrapper(env, illegal_reward=-1)
     env = wrappers.AssertOutOfBoundsWrapper(env)
-    pass_action = 2
-    env = wrappers.NanNoOpWrapper(env, pass_action, "'checked' with action {}".format(pass_action))
     env = wrappers.OrderEnforcingWrapper(env)
     return env
 
@@ -26,7 +24,9 @@ class raw_env(RLCardBase):
 
     def __init__(self):
         super().__init__("no-limit-holdem", 2, (54,))
-        self.observation_spaces = self._convert_to_dict([spaces.Box(low=np.zeros(54,), high=np.append(np.ones(52,), [100, 100]), dtype=np.float32) for _ in range(self.num_agents)])
+        self.observation_spaces = self._convert_to_dict([spaces.Dict(
+            {'observation': spaces.Box(low=np.zeros(54, ), high=np.append(np.ones(52, ), [100, 100]), dtype=np.int8),
+             'action_mask': spaces.Box(low=0, high=1, shape=(6,), dtype=np.int8)}) for _ in range(self.num_agents)])
 
     def render(self, mode='human'):
         for player in self.possible_agents:
