@@ -16,7 +16,6 @@ def env():
     env = raw_env()
     env = wrappers.CaptureStdoutWrapper(env)
     env = wrappers.AssertOutOfBoundsWrapper(env)
-    env = wrappers.NaNRandomWrapper(env)
     env = wrappers.OrderEnforcingWrapper(env)
     return env
 
@@ -38,9 +37,6 @@ class raw_env(AECEnv):
         self.display_wait = 0.0
         self.reinit()
 
-    def seed(self, seed=None):
-        pass
-
     def reinit(self):
         self.agents = self.possible_agents[:]
         self._agent_selector = agent_selector(self.agents)
