@@ -11,6 +11,8 @@ def manual_control(**kwargs):
     n_evaders = 1
     n_pursuers = 2
 
+    clock = pygame.time.Clock()
+
     # obs_range should be odd 3, 5, 7, etc
     env = _env(n_pursuers=n_pursuers, n_evaders=n_evaders,
                xs=xs, ys=ys, obs_range=obs_range)
@@ -29,6 +31,7 @@ def manual_control(**kwargs):
     total_reward = 0
 
     while not done:
+        clock.tick(15)
         num_frames += 1
         env.render()
         if _quit_loop[0]:
@@ -62,8 +65,9 @@ def manual_control(**kwargs):
                     # break
         # actions should be a dict of numpy arrays
         for a in _actions:
-            reward, d, info = env.last()
+            obs, reward, d, info = env.last()
             env.step(a)
+            pygame.event.pump()
             if d:
                 done = True
             total_reward += reward
