@@ -260,10 +260,14 @@ class Pursuit():
             pygame.draw.circle(self.screen, col, center, int(self.pixel_scale / 3))
 
     def render(self, mode="human"):
-        if not self.renderOn and mode == "human":
-            pygame.display.init()
-            self.screen = pygame.display.set_mode(
-                (self.pixel_scale * self.x_size, self.pixel_scale * self.y_size))
+        if not self.renderOn:
+            if mode == "human":
+                pygame.display.init()
+                self.screen = pygame.display.set_mode(
+                    (self.pixel_scale * self.x_size, self.pixel_scale * self.y_size))
+            else:
+                self.screen = pygame.Surface((self.pixel_scale * self.x_size, self.pixel_scale * self.y_size))
+
             self.renderOn = True
         self.draw_model_state()
 
@@ -275,7 +279,8 @@ class Pursuit():
         observation = pygame.surfarray.pixels3d(self.screen)
         new_observation = np.copy(observation)
         del observation
-        pygame.display.flip()
+        if mode == "human":
+            pygame.display.flip()
         return np.transpose(new_observation, axes=(1, 0, 2)) if mode == "rgb_array" else None
 
     def animate(self, act_fn, nsteps, file_name, rate=1.5, verbose=False):
@@ -351,8 +356,9 @@ class Pursuit():
         return obs
 
     def collect_obs(self, agent_layer, i):
-        for i in range(self.n_agents()):
-            return self.collect_obs_by_idx(agent_layer, i)
+        for j in range(self.n_agents()):
+            if i == j:
+                return self.collect_obs_by_idx(agent_layer, i)
         assert False, "bad index"
 
     def collect_obs_by_idx(self, agent_layer, agent_idx):
