@@ -9,7 +9,6 @@ from pettingzoo.utils.to_parallel import parallel_wrapper_fn
 def env(**kwargs):
     env = raw_env(**kwargs)
     env = wrappers.ClipOutOfBoundsWrapper(env)
-    env = wrappers.NanZerosWrapper(env)
     env = wrappers.OrderEnforcingWrapper(env)
     return env
 
@@ -67,11 +66,12 @@ class raw_env(AECEnv):
 
         is_last = self._agent_selector.is_last()
         self.env.step(action, self.agent_name_mapping[agent], is_last)
+
+        for r in self.rewards:
+            self.rewards[r] = self.env.control_rewards[self.agent_name_mapping[r]]
         if is_last:
             for r in self.rewards:
-                self.rewards[r] = self.env.last_rewards[self.agent_name_mapping[r]]
-        else:
-            self._clear_rewards()
+                self.rewards[r] += self.env.last_rewards[self.agent_name_mapping[r]]
 
         if self.env.frames >= self.env.max_cycles:
             self.dones = dict(zip(self.agents, [True for _ in self.agents]))
