@@ -36,10 +36,6 @@ class EnvLogger():
     def warn_action_out_of_bound(action, action_space, backup_policy):
         EnvLogger._generic_warning("[WARNING]: Received an action {} that was outside action space {}. Environment is {}".format(action, action_space, backup_policy))
 
-    @staticmethod
-    def warn_action_is_NaN(backup_policy):
-        EnvLogger._generic_warning("[WARNING]: Received an NaN action. Environment is {}".format(backup_policy))
-
     @staticmethod
     def warn_close_unrendered_env():
         EnvLogger._generic_warning("[WARNING]: Called close on an unrendered environment.")
@@ -50,7 +46,7 @@ class EnvLogger():
 
     @staticmethod
     def warn_on_illegal_move():
-        EnvLogger._generic_warning("[WARNING]: Illegal move made, game terminating with current player losing. \nenv.infos[player]['legal_moves'] contains a list of all legal moves that can be chosen.")
+        EnvLogger._generic_warning("[WARNING]: Illegal move made, game terminating with current player losing. \nobs['action_mask'] contains a mask of all legal moves that can be chosen.")
 
     @staticmethod
     def error_observe_before_reset():
@@ -68,10 +64,6 @@ class EnvLogger():
     def error_render_before_reset():
         assert False, "reset() needs to be called before render"
 
-    @staticmethod
-    def error_field_before_reset(field):
-        assert False, "{} cannot be accessed before reset".format(field)
-
 
 class EnvWarningHandler(logging.Handler):
     def __init__(self, *args, mqueue, **kwargs):
