@@ -1,7 +1,7 @@
-from cv2 import imwrite
 import numpy as np
 import gym
 import os
+from PIL import Image
 
 
 def _check_observation_saveable(env, agent):
@@ -26,5 +26,7 @@ def save_observation(env, agent=None, all_agents=False, save_dir=os.getcwd()):
         os.makedirs(save_folder, exist_ok=True)
 
         observation = env.observe(a)
+        rescaled = observation.astype(np.uint8)
+        im = Image.fromarray(rescaled)
         fname = os.path.join(save_folder, str(a) + ".png")
-        imwrite(fname, observation)
+        im.save(fname)
